@@ -40,7 +40,9 @@ class EnviarPedido(Plugavel):
         if type(dados is dict):
             dados = json.dumps(dados)
         resposta = requests.post(self.requisicao.url, data=dados, headers=self.headers)
-        return self.processar_resposta(resposta)
+        resposta = self.processar_resposta(resposta)
+        notificador.grava_evidencia_envio(self.meio_pagamento, para=self.requisicao.url, dados=dados, resposta=resposta)
+        return resposta
 
     def enviar(self):
         resultado = self.post()
