@@ -29,7 +29,7 @@ class Credenciais(base.Plugavel):
     def credenciador(self):
         if not self._credenciador:
             try:
-                self._credenciador = self.plugin_autenticador.Credenciador(self.configuracao_pagamento)
+                self._credenciador = self.plugin_seguranca.Credenciador(self.configuracao_pagamento)
             except AttributeError:
                 raise AutenticadorNaoEncontrado(u"O meio de pagamento '{}' não possui a classe Credenciador.".format(self.meio_pagamento))
         return self._credenciador
